==> sqldb-orm-1.0.9.tgz: package/dal/sqlite3-base.js <==
const sqlite3 = require("sqlite3").verbose();
const DbBase = require("./db-base");
let dbs = {};

module.exports = class Sqlite3Base extends DbBase {
  constructor(dbFile, tableName, showSqlStr) {
    if (!dbFile || typeof dbFile != "string") {
      dbFile = "./db.sqlite3";
    }
    let conn = dbs[dbFile];
    if (!conn) {
      conn = new sqlite3.Database(dbFile);
      dbs[dbFile] = conn;
    }
    super(tableName, showSqlStr);
    this.conn = conn;
  }
  static testConnect(dbFile) {
    return new Promise((resolve, reject) => {
      try {
        let conn = new sqlite3.Database(dbFile, function (err) {
          if (err) {
            return resolve(false);
          }
          let sql =
            "select name as table_name from sqlite_master where type='table'";
          conn.all(sql, function (error, data) {
            if (error) {
              return resolve(false);
            } else {
              conn.close(function () {
                resolve(Array.isArray(data));
              });
            }
          });
        });
      } catch (e) {
        resolve(false);
      }
    });
  }
  query(sqlStr, params) {
    if (this.showSqlStr) {
      console.log(sqlStr, params);
    }
    return new Promise((resolve, reject) => {
      if (sqlStr.indexOf("??") != -1) {
        sqlStr = sqlStr.replace("??", params[0]);
        params = params.slice(1);
      }
      if (sqlStr.indexOf("select") == 0) {
        this.conn.all(sqlStr, params, function (err, data) {
          if (err) {
            reject(err);
          } else {
            resolve(data);
          }
        });
      } else {
        this.conn.run(sqlStr, params, function (err) {
          if (err) {
            reject(err);
          } else {
            resolve(this);
          }
        });
      }
    });
  }

  insert(entity, checkQuery) {
    return new Promise(async (resolve, reject) => {
      try {
        const { keys, sp, values } = formatEntity(entity);
        if (checkQuery) {
          let result = await this.findOne(checkQuery);
          if (result && result.length > 0) {
            ret.msg = "Duplicate content.";
            return resolve(ret);
          }
        }
        let sql =
          "insert into " +
          this.tableName +
          " (" +
          keys.join(",") +
          ") values (" +
          sp.join(",") +
          ")";
        let result = await this.query(sql, values);
        resolve({ msg: "ok", id: result.lastID });
      } catch (e) {
        resolve({ msg: e.message || "error", err: e });
      }
    });
  }

  truncate(tableName) {
    if (!tableName) {
      tableName = this.tableName;
    }
    let sql = "delete from " + tableName;
    this.query(sql);
    let sql2 =
      "UPDATE sqlite_sequence SET seq = 0 WHERE name = '" + tableName + "'";
    return this.query(sql2);
  }

  update(entity, whereStr) {
    const { values, keystr } = formatEntity(entity);
    let sql =
      "update " + this.tableName + " set " + keystr + " where " + whereStr;
    return this.query(sql, values);
  }

  updateByParams(entity, where) {
    let { values, keystr } = formatEntity(entity);
    const t = formatEntity(where, " and ");
    values = values.concat(t.values);
    let sql =
      "update " + this.tableName + " set " + keystr + " where " + t.keystr;

    return this.query(sql, values);
  }

  updateById(entity, id) {
    const { values, keystr } = formatEntity(entity);
    values.push(id);
    let sql = "update " + this.tableName + " set " + keystr + " where id=?";
    return this.query(sql, values);
  }
  findOne(query) {
    const { values, keystr } = formatEntity(query, " and ");
    let sql =
      "select * from " +
      this.tableName +
      " where " +
      keystr +
      " order by id desc limit 1";
    return this.query(sql, values);
  }

  findWithQuery(query) {
    const { values, keystr } = formatEntity(query);
    let sql = "select * from " + this.tableName + " where " + keystr;
    return this.query(sql, values);
  }

  getTableNames() {
    let sql = "select name as table_name from sqlite_master where type='table'";
    return this.query(sql);
  }

  findColumnName(tableName) {
    return new Promise(async (resolve, reject) => {
      try {
        let tn = tableName || this.tableName;
        let sql = "PRAGMA table_info('" + tn + "')";
        this.conn.all(sql, function (err, data) {
          if (err) {
            reject(err);
          } else {
            let arr = data.map((t) => {
              return {
                column_name: t.name,
                column_comment: t.name,
                column_type: t.type,
              };
            });
            resolve(arr);
          }
        });
      } catch (e) {
        reject(e);
      }
    });
  }
};

function formatEntity(entity, separate) {
  let keys = [], // ["a","b","c"]
    sp = [], // ?,?
    values = [], //[1,2,3]
    keyarr = []; // a=?,b=?
  Object.keys(entity).forEach((k) => {
    let key = "`" + k + "`";
    keys.push(key);
    sp.push("?");
    values.push(entity[k]);
    keyarr.push(key + "=?");
  });
  let keystr = keyarr.join(separate || ",");
  return { keys, sp, values, keystr };
}

==> sqldb-orm-1.1.0.tgz: package/dal/sqlite3-base.js <==
const sqlite3 = require("sqlite3");
const DbBase = require("./db-base");
let dbs = {};

module.exports = class Sqlite3Base extends DbBase {
  constructor(dbFile, tableName, showSqlStr) {
    if (!dbFile || typeof dbFile != "string") {
      dbFile = "./db.sqlite3";
    }
    let conn = dbs[dbFile];
    if (!conn) {
      conn = new sqlite3.Database(dbFile);
      dbs[dbFile] = conn;
    }
    super(tableName, showSqlStr);
    this.conn = conn;
  }
  static testConnect(dbFile) {
    return new Promise((resolve, reject) => {
      try {
        let conn = new sqlite3.Database(dbFile, function (err) {
          if (err) {
            return resolve(false);
          }
          let sql =
            "select name as table_name from sqlite_master where type='table'";
          conn.all(sql, function (error, data) {
            if (error) {
              return resolve(false);
            } else {
              conn.close(function () {
                resolve(Array.isArray(data));
              });
            }
          });
        });
      } catch (e) {
        resolve(false);
      }
    });
  }
  query(sqlStr, params) {
    if (this.showSqlStr) {
      console.log(sqlStr, params);
    }
    return new Promise((resolve, reject) => {
      if (sqlStr.indexOf("??") != -1) {
        sqlStr = sqlStr.replace("??", params[0]);
        params = params.slice(1);
      }
      if (sqlStr.toLocaleLowerCase().indexOf("select") == 0) {
        this.conn.all(sqlStr, params, function (err, data) {
          if (err) {
            reject(err);
          } else {
            resolve(data);
          }
        });
      } else {
        this.conn.run(sqlStr, params, function (err) {
          if (err) {
            reject(err);
          } else {
            resolve(this);
          }
        });
      }
    });
  }

  insert(entity, checkQuery) {
    return new Promise(async (resolve, reject) => {
      try {
        const { keys, sp, values } = formatEntity(entity);
        if (checkQuery) {
          let result = await this.findOne(checkQuery);
          if (result && result.length > 0) {
            ret.msg = "Duplicate content.";
            return resolve(ret);
          }
        }
        let sql =
          "insert into " +
          this.tableName +
          " (" +
          keys.join(",") +
          ") values (" +
          sp.join(",") +
          ")";
        let result = await this.query(sql, values);
        resolve({ msg: "ok", id: result.lastID });
      } catch (e) {
        resolve({ msg: e.message || "error", err: e });
      }
    });
  }

  truncate(tableName) {
    if (!tableName) {
      tableName = this.tableName;
    }
    let sql = "delete from " + tableName;
    this.query(sql);
    let sql2 =
      "UPDATE sqlite_sequence SET seq = 0 WHERE name = '" + tableName + "'";
    return this.query(sql2);
  }

  update(entity, whereStr) {
    const { values, keystr } = formatEntity(entity);
    let sql =
      "update " + this.tableName + " set " + keystr + " where " + whereStr;
    return this.query(sql, values);
  }

  updateByParams(entity, where) {
    let { values, keystr } = formatEntity(entity);
    const t = formatEntity(where, " and ");
    values = values.concat(t.values);
    let sql =
      "update " + this.tableName + " set " + keystr + " where " + t.keystr;

    return this.query(sql, values);
  }

  updateById(entity, id) {
    const { values, keystr } = formatEntity(entity);
    values.push(id);
    let sql = "update " + this.tableName + " set " + keystr + " where id=?";
    return this.query(sql, values);
  }
  findOne(query) {
    const { values, keystr } = formatEntity(query, " and ");
    let sql =
      "select * from " +
      this.tableName +
      " where " +
      keystr +
      " order by id desc limit 1";
    return this.query(sql, values);
  }

  findWithQuery(query) {
    const { values, keystr } = formatEntity(query);
    let sql = "select * from " + this.tableName + " where " + keystr;
    return this.query(sql, values);
  }

  getTableNames() {
    let sql = "select name as table_name from sqlite_master where type='table'";
    return this.query(sql);
  }

  findColumnName(tableName) {
    return new Promise(async (resolve, reject) => {
      try {
        let tn = tableName || this.tableName;
        let sql = "PRAGMA table_info('" + tn + "')";
        this.conn.all(sql, function (err, data) {
          if (err) {
            reject(err);
          } else {
            let arr = data.map((t) => {
              return {
                column_name: t.name,
                column_comment: t.name,
                column_type: t.type,
              };
            });
            resolve(arr);
          }
        });
      } catch (e) {
        reject(e);
      }
    });
  }
};

function formatEntity(entity, separate) {
  let keys = [], // ["a","b","c"]
    sp = [], // ?,?
    values = [], //[1,2,3]
    keyarr = []; // a=?,b=?
  Object.keys(entity).forEach((k) => {
    let key = "`" + k + "`";
    keys.push(key);
    sp.push("?");
    values.push(entity[k]);
    keyarr.push(key + "=?");
  });
  let keystr = keyarr.join(separate || ",");
  return { keys, sp, values, keystr };
}
